#
# spec file for package qimageblitz
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname_qt5 libqimageblitz5
%define sover_qt5 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%bcond_with qt4
%else
%bcond_without qt4
%define soname_qt4 libqimageblitz
%define sover_qt4 4
%endif
Name:           qimageblitz
Version:        0.0.6+svn1515099
Release:        bp155.2.18
Summary:        Graphical effect and filter library for Qt
License:        BSD-2-Clause
Group:          System/Libraries
URL:            https://websvn.kde.org/trunk/kdesupport/qimageblitz
Source0:        %{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE qimageblitz-qt5-fix-soname.patch sor.alexei@meowr.ru -- Change the soname for Qt5 to fix a conflict with Qt4.
Patch0:         qimageblitz-qt5-fix-soname.patch
# PATCH-FIX-UPSTREAM
Patch1:         remove-ansi-option.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
%if %{with qt4}
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
%endif

%description
qimageblitz is a graphical effect and filter library for Qt that
contains many improvements over KDE 3.x's kdefx library including
bugfixes, memory and speed improvements, and MMX/SSE support.

%if %{with qt4}
%package -n %{soname_qt4}%{sover_qt4}
Summary:        Graphical effect and filter library for Qt4
Group:          System/Libraries

%description -n %{soname_qt4}%{sover_qt4}
libqimageblitz is a graphical effect and filter library for Qt4
that contains many improvements over KDE 3.x's kdefx library
including bugfixes, memory and speed improvements, and MMX/SSE
support.
%endif

%package -n %{soname_qt5}-%{sover_qt5}
Summary:        Graphical effect and filter library for Qt5
Group:          System/Libraries

%description -n %{soname_qt5}-%{sover_qt5}
libqimageblitz5 is a graphical effect and filter library for Qt5
that contains many improvements over KDE 3.x's kdefx library
including bugfixes, memory and speed improvements, and MMX/SSE
support.

%if %{with qt4}
%package -n %{soname_qt4}-devel
Summary:        Development files for libqimageblitz4
Group:          Development/Libraries/C and C++
Requires:       %{soname_qt4}%{sover_qt4} = %{version}

%description -n %{soname_qt4}-devel
This package contains development files for libqimageblitz.
%endif

%package -n %{soname_qt5}-devel
Summary:        Development files for libqimageblitz5
Group:          Development/Libraries/C and C++
Requires:       %{soname_qt5}-%{sover_qt5} = %{version}

%description -n %{soname_qt5}-devel
This package contains development files for libqimageblitz5.

%prep
%autosetup -p1

%build
WORKDIR="$PWD"
%define __builddir build-qt5
%cmake -DQT4_BUILD=OFF
make %{?_smp_mflags} V=1

%if %{with qt4}
cd "$WORKDIR"
%define __builddir build-qt4
%cmake -DQT4_BUILD=ON
make %{?_smp_mflags} V=1
%endif

%install
WORKDIR="$PWD"
%define __builddir build-qt5
%cmake_install

%if %{with qt4}
cd "$WORKDIR"
%define __builddir build-qt4
%cmake_install
%endif

%if %{with qt4}
%post -n %{soname_qt4}%{sover_qt4} -p /sbin/ldconfig

%postun -n %{soname_qt4}%{sover_qt4} -p /sbin/ldconfig
%endif

%post -n %{soname_qt5}-%{sover_qt5} -p /sbin/ldconfig

%postun -n %{soname_qt5}-%{sover_qt5} -p /sbin/ldconfig

%if %{with qt4}
%files -n %{soname_qt4}%{sover_qt4}
%if 0%{?suse_version} == 1500
%license COPYING
%else
%doc COPYING
%endif
%doc Changelog README.*
%{_libdir}/%{soname_qt4}.so.%{sover_qt4}*
%endif

%files -n %{soname_qt5}-%{sover_qt5}
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc Changelog README.*
%{_libdir}/%{soname_qt5}.so.%{sover_qt5}*

%if %{with qt4}
%files -n %{soname_qt4}-devel
%{_includedir}/qimageblitz/
%{_bindir}/blitztest
%{_libdir}/%{soname_qt4}.so
%{_libdir}/pkgconfig/qimageblitz.pc
%endif

%files -n %{soname_qt5}-devel
%{_includedir}/qimageblitz5/
%{_bindir}/blitztest5
%{_libdir}/%{soname_qt5}.so
%{_libdir}/pkgconfig/qimageblitz5.pc

%changelog
* Wed Dec  9 2020 Antonio Larrosa <alarrosa@suse.com>
- Only build the qt4 subpackage up to Leap 15.2 / SLE 15 SP2
  (boo#1179613)
* Mon Oct 14 2019 Christophe Giboudeaux <christophe@krop.fr>
- Stop packaging qimageblitz4 for Tumbleweed.
* Wed Jul 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with newer CMake:
  * remove-ansi-option.patch
* Fri May 18 2018 sor.alexei@meowr.ru
- Update to version 0.0.6+svn1515099 (changes since
  0.0.6+svn1368047):
  * Allow building with Qt 5.11.
    qt5_use_modules is no longer present in Qt 5.11. Fix build by
    moving to target_link_libraries
    This also adds a dependency on Qt5 Widgets (used by the test).
- Rebase qimageblitz-qt5-fix-soname.patch.
* Mon Jan  8 2018 sor.alexei@meowr.ru
- Update to version 0.0.6+svn1368047:
  * Apply some more GCC flags also on GNU/Hurd.
  * Use the autodetected CMAKE_C_COMPILER instead of hardwired GCC.
    Fixes build with compilers other than GCC.
  * Merge Fedora's patch for non-executable stack (makes SELinux
    happier).
  * Add a minimum cmake version.
  * Remove this outdated FindQt4. cmake 2.6.4 has a way better one.
  * "comparison is always true due to limited range of data type",
    which means some compiler could have made that loop run
    endless.
  * Port away from Qt3Support
  * Enable compilation with Qt5, but skip cpptoxml.
- Remove qimageblitz-0.0.4-noexecstack.patch: fixed upstream.
- Add qimageblitz-qt5-fix-soname.patch: Change the soname for Qt5
  to fix a conflict with Qt4.
- Build for Qt5 too.
- Rename the source package to qimageblitz from libqimageblitz4.
- Move the docfiles from the devel package to the library package.
- Spec cleanup.
* Mon Jun 10 2013 cfarrell@suse.com
- license update: BSD-2-Clause
  See COPYING
* Mon May 16 2011 asterios.dramis@gmail.com
- Update to 0.0.6
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changes in Group, Url, Summary and %%description entries.
  * Removed Provides/Obsoletes entries for libblitz4.
  * Removed %%changelog entries.
  * Minor other updates.
- Added a patch (taken from Fedora) to fix "executable-stack" rpmlint warning.
* Sun Apr 13 2008 dmueller@suse.de
- fix build against cmake 2.6
* Thu Jan 10 2008 dmueller@suse.de
- update to 0.0.4 (official release):
  * small bugfixes
* Sat Sep  1 2007 stbinner@suse.de
- rename to libqimageblitz4 and update to SVN version
* Wed Aug 15 2007 dmueller@suse.de
- Initial package
